import platform

from coalib.bearlib.abstractions.CorrectionBasedBear import CorrectionBasedBear


class IndentBear(CorrectionBasedBear):
    BINARY = "indent" if platform.system() != "Darwin" else "gindent"
    RESULT_MESSAGE = "Indentation can be improved."

    def run(self,
            filename,
            file,
            indent_cli_options: str='--k-and-r-style'):
        """
        This bear checks and corrects spacing and indentation via the well
        known Indent utility. It is designed to work with the C programming
        language but may work reasonably with syntactically similar languages.

        :param indent_cli_options: Any command line options the indent binary
                                   understands. They will be simply passed
                                   through.
        """
        for result in self.retrieve_results(filename,
                                            file,
                                            cli_options=indent_cli_options):
            yield result



import autopep8

from coalib.bearlib.abstractions.CorrectionBasedBear import CorrectionBasedBear
from coalib.settings.Setting import typed_list


class PEP8Bear(CorrectionBasedBear):
    RESULT_MESSAGE = "The code does not comply to PEP8."

    @staticmethod
    def run_autopep(file, pep_ignore, pep_select):
        new_file = autopep8.fix_code(''.join(file),
                                     options={'ignore': pep_ignore,
                                              'select': pep_select})

        return new_file.splitlines(True), []

    GET_REPLACEMENT = run_autopep

    def run(self,
            filename,
            file,
            pep_ignore: typed_list(str)=(),
            pep_select: typed_list(str)=()):
        """
        Detects and fixes PEP8 incompliant code. This bear will not change
        functionality of the code in any way.

        :param pep_ignore: A list of errors/warnings to ignore.
        :param pep_select: A list of errors/warnings to exclusively apply.
        """
        for result in self.retrieve_results(filename,
                                            file,
                                            pep_ignore=pep_ignore,
                                            pep_select=pep_select):
            yield result
